@@ -297,6 +297,9 @@ gnc_budget_view_finalize (GObject *object)
 
     priv = GNC_BUDGET_VIEW_GET_PRIVATE(budget_view);
 
+    g_list_free (priv->period_col_list);
+    g_list_free (priv->totals_col_list);
+
     gnc_prefs_remove_cb_by_func (GNC_PREFS_GROUP_GENERAL, GNC_PREF_GRID_LINES_HORIZONTAL,
                                  gbv_treeview_update_grid_lines, priv->totals_tree_view);
     gnc_prefs_remove_cb_by_func (GNC_PREFS_GROUP_GENERAL, GNC_PREF_GRID_LINES_VERTICAL,
@@ -636,6 +639,7 @@ gnc_budget_view_restore (GncBudgetView *budget_view, GKeyFile *key_file, const g
     GncGUID guid;
     GncBudget *bgt;
     QofBook *book;
+    gboolean has_guid;
 
     g_return_val_if_fail (key_file, FALSE);
     g_return_val_if_fail (group_name, FALSE);
@@ -652,7 +656,10 @@ gnc_budget_view_restore (GncBudgetView *budget_view, GKeyFile *key_file, const g
         error = NULL;
         return FALSE;
     }
-    if (!string_to_guid (guid_str, &guid))
+    has_guid = string_to_guid (guid_str, &guid);
+    g_free (guid_str);
+
+    if (!has_guid)
     {
         return FALSE;
     }
@@ -1629,7 +1636,7 @@ gnc_budget_view_refresh (GncBudgetView *budget_view)
         if (col != NULL)
         {
             gtk_tree_view_append_column (priv->totals_tree_view, col);
-            totals_col_list = g_list_append (totals_col_list, col);
+            totals_col_list = g_list_prepend (totals_col_list, col);
         }
 
         num_periods_visible = g_list_length (col_list);
@@ -1639,7 +1646,7 @@ gnc_budget_view_refresh (GncBudgetView *budget_view)
     gdk_rgba_free (note_color_selected);
 
     priv->period_col_list = col_list;
-    priv->totals_col_list = totals_col_list;
+    priv->totals_col_list = g_list_reverse (totals_col_list);
 
     if (priv->total_col == NULL)
     {
