@@ -42,12 +42,18 @@
 #include <glib/gi18n.h>
 #include "gnc-date-edit.h"
 
+#include "swig-runtime.h"
+#include "libguile.h"
+
 #include "gnc-plugin-page-register.h"
+#include "gnc-plugin-page-report.h"
 #include "gnc-budget.h"
+#include "gnc-features.h"
 
 #include "dialog-options.h"
 #include "dialog-utils.h"
 #include "gnc-gnome-utils.h"
+#include "misc-gnome-utils.h"
 #include "gnc-gobject-utils.h"
 #include "gnc-icons.h"
 #include "gnc-plugin-page-budget.h"
@@ -123,6 +129,12 @@ static void gnc_plugin_page_budget_cmd_allperiods_budget (GtkAction *action,
                                                           GncPluginPageBudget *page);
 static void gnc_plugin_page_budget_cmd_refresh (GtkAction *action,
                                                 GncPluginPageBudget *page);
+static void gnc_plugin_page_budget_cmd_budget_note (GtkAction *action,
+                                                    GncPluginPageBudget *page);
+static void gnc_plugin_page_budget_cmd_budget_report (GtkAction *action,
+                                                      GncPluginPageBudget *page);
+static void allperiods_budget_helper (GtkTreeModel *model, GtkTreePath *path,
+                                      GtkTreeIter *iter, gpointer data);
 
 static GtkActionEntry gnc_plugin_page_budget_actions [] =
 {
@@ -132,40 +144,51 @@ static GtkActionEntry gnc_plugin_page_budget_actions [] =
     /* File menu */
     {
         "OpenAccountAction", GNC_ICON_OPEN_ACCOUNT, N_("Open _Account"), NULL,
-        N_("Open the selected account"),
+        N_("Open the selected account."),
         G_CALLBACK(gnc_plugin_page_budget_cmd_open_account)
     },
     {
         "OpenSubaccountsAction", GNC_ICON_OPEN_ACCOUNT,
         N_("Open _Subaccounts"), NULL,
-        N_("Open the selected account and all its subaccounts"),
+        N_("Open the selected account and all its subaccounts."),
         G_CALLBACK(gnc_plugin_page_budget_cmd_open_subaccounts)
     },
 
     /* Edit menu */
     {
-        "DeleteBudgetAction", GNC_ICON_DELETE_BUDGET, N_("_Delete Budget"),
-        NULL, N_("Delete this budget"),
+        "DeleteBudgetAction", GNC_ICON_DELETE_BUDGET, N_("_Delete Budget..."),
+        NULL, N_("Select this or another budget and delete it."),
         G_CALLBACK(gnc_plugin_page_budget_cmd_delete_budget)
     },
     {
-        "OptionsBudgetAction", "document-properties", N_("Budget Options"),
-        NULL, N_("Edit this budget's options"),
+        "OptionsBudgetAction", "document-properties", N_("Budget _Options..."),
+        NULL, N_("Edit this budget's options."),
         G_CALLBACK(gnc_plugin_page_budget_cmd_view_options)
     },
     {
-        "EstimateBudgetAction", "system-run", N_("Estimate Budget"),
+        "EstimateBudgetAction", "system-run", N_("Esti_mate Budget..."),
         NULL,
-        N_("Estimate a budget value for the selected accounts from past transactions"),
+        N_("Estimate a budget value for the selected accounts from past transactions."),
         G_CALLBACK(gnc_plugin_page_budget_cmd_estimate_budget)
     },
     {
-        "AllPeriodsBudgetAction", "system-run", N_("All Periods"),
+        "AllPeriodsBudgetAction", "system-run", N_("_All Periods..."),
         NULL,
-        N_("Edit budget for all periods for the selected accounts"),
+        N_("Edit budget for all periods for the selected accounts."),
         G_CALLBACK(gnc_plugin_page_budget_cmd_allperiods_budget)
     },
-
+    {
+        "BudgetNoteAction", "text-x-generic", N_("Edit Note"),
+        NULL,
+        N_("Edit note for the selected account and period."),
+        G_CALLBACK (gnc_plugin_page_budget_cmd_budget_note)
+    },
+    {
+        "BudgetReportAction", "system-run", N_("Budget Report"),
+        NULL,
+        N_("Run the budget report."),
+        G_CALLBACK (gnc_plugin_page_budget_cmd_budget_report)
+    },
     /* View menu */
     {
         "ViewFilterByAction", NULL, N_("_Filter By..."), NULL, NULL,
@@ -173,7 +196,7 @@ static GtkActionEntry gnc_plugin_page_budget_actions [] =
     },
     {
         "ViewRefreshAction", "view-refresh", N_("_Refresh"), "<primary>r",
-        N_("Refresh this window"),
+        N_("Refresh this window."),
         G_CALLBACK(gnc_plugin_page_budget_cmd_refresh)
     },
 
@@ -199,6 +222,8 @@ static action_toolbar_labels toolbar_labels[] =
     { "OptionsBudgetAction",        N_("Options") },
     { "EstimateBudgetAction",       N_("Estimate") },
     { "AllPeriodsBudgetAction",     N_("All Periods") },
+    { "BudgetNoteAction",           N_("Note") },
+    { "BudgetReportAction",         N_("Run Report") },
     { NULL, NULL },
 };
 
@@ -238,6 +263,10 @@ typedef struct GncPluginPageBudgetPrivate
     gnc_numeric allValue;
     allperiods_action action;
 
+    /* the cached reportPage for this budget. note this is not saved
+       into .gcm file therefore the budget editor->report link is lost
+       upon restart. */
+    GncPluginPage *reportPage;
 } GncPluginPageBudgetPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE(GncPluginPageBudget, gnc_plugin_page_budget, GNC_TYPE_PLUGIN_PAGE)
@@ -277,6 +306,7 @@ gnc_plugin_page_budget_new (GncBudget *budget)
     priv->budget = budget;
     priv->delete_budget = FALSE;
     priv->key = *gnc_budget_get_guid (budget);
+    priv->reportPage = NULL;
     label = g_strdup_printf ("%s: %s", _("Budget"), gnc_budget_get_name (budget));
     g_object_set (G_OBJECT(plugin_page), "page-name", label, NULL);
     g_free (label);
@@ -793,6 +823,8 @@ gnc_plugin_page_budget_cmd_view_options (GtkAction *action,
 
     GtkTextBuffer *buffer;
     GtkTextIter start, end;
+    GtkWidget *show_account_code, *show_account_desc;
+    gboolean show_ac, show_ad;
 
     g_return_if_fail (GNC_IS_PLUGIN_PAGE_BUDGET(page));
     priv = GNC_PLUGIN_PAGE_BUDGET_GET_PRIVATE(page);
@@ -824,6 +856,15 @@ gnc_plugin_page_budget_cmd_view_options (GtkAction *action,
         gbnumperiods = GTK_WIDGET(gtk_builder_get_object (builder, "BudgetNumPeriods"));
         gtk_spin_button_set_value (GTK_SPIN_BUTTON(gbnumperiods), gnc_budget_get_num_periods (priv->budget));
 
+        show_account_code = GTK_WIDGET(gtk_builder_get_object (builder, "ShowAccountCode"));
+        show_account_desc = GTK_WIDGET(gtk_builder_get_object (builder, "ShowAccountDescription"));
+
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(show_account_code),
+                                      gnc_budget_view_get_show_account_code (priv->budget_view));
+
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(show_account_desc),
+                                      gnc_budget_view_get_show_account_description (priv->budget_view));
+
         gtk_widget_show_all (priv->dialog);
         result = gtk_dialog_run (GTK_DIALOG(priv->dialog));
 
@@ -847,6 +888,19 @@ gnc_plugin_page_budget_cmd_view_options (GtkAction *action,
             gnc_budget_set_description (priv->budget, desc);
             g_free (desc);
 
+            show_ac = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(show_account_code));
+            gnc_budget_view_set_show_account_code (priv->budget_view, show_ac);
+
+            show_ad = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(show_account_desc));
+            gnc_budget_view_set_show_account_description (priv->budget_view, show_ad);
+
+            // if show account code or description is set then set feature
+            if ((show_ac || show_ad) && (!gnc_features_check_used (gnc_get_current_book (),
+                                           GNC_FEATURE_BUDGET_SHOW_EXTRA_ACCOUNT_COLS)))
+            {
+                gnc_features_set_used (gnc_get_current_book (), GNC_FEATURE_BUDGET_SHOW_EXTRA_ACCOUNT_COLS);
+            }
+
             num_periods = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(gbnumperiods));
             gnc_budget_set_num_periods (priv->budget, num_periods);
 
@@ -1156,6 +1210,127 @@ gnc_plugin_page_budget_cmd_allperiods_budget (GtkAction *action,
     g_object_unref (G_OBJECT(builder));
 }
 
+static void
+gnc_plugin_page_budget_cmd_budget_note(GtkAction *action,
+                                       GncPluginPageBudget *page)
+{
+    GncPluginPageBudgetPrivate *priv;
+    GtkTreeSelection *sel;
+    GtkWidget *dialog, *note;
+    gint result;
+    GtkBuilder *builder;
+    const gchar *txt;
+    GtkTreeViewColumn *col = NULL;
+    GtkTreePath *path = NULL;
+    guint period_num = 0;
+    Account *acc = NULL;
+
+    g_return_if_fail(GNC_IS_PLUGIN_PAGE_BUDGET(page));
+    priv = GNC_PLUGIN_PAGE_BUDGET_GET_PRIVATE(page);
+    sel  = gnc_budget_view_get_selection(priv->budget_view);
+
+    gtk_tree_view_get_cursor(
+        GTK_TREE_VIEW(gnc_budget_view_get_account_tree_view(priv->budget_view)),
+        &path, &col);
+
+    if (path)
+    {
+        period_num = col ? GPOINTER_TO_UINT(
+                               g_object_get_data(G_OBJECT(col), "period_num"))
+                         : 0;
+
+        acc = gnc_budget_view_get_account_from_path(priv->budget_view, path);
+        gtk_tree_path_free(path);
+    }
+
+    if (!acc)
+    {
+        dialog = gtk_message_dialog_new(
+            GTK_WINDOW(gnc_plugin_page_get_window(GNC_PLUGIN_PAGE(page))),
+            GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
+            GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, "%s",
+            _("You must select one budget cell to edit."));
+        gtk_dialog_run(GTK_DIALOG(dialog));
+        gtk_widget_destroy(dialog);
+        return;
+    }
+
+    builder = gtk_builder_new();
+    gnc_builder_add_from_file(builder, "gnc-plugin-page-budget.glade",
+                              "budget_note_dialog");
+
+    dialog = GTK_WIDGET(gtk_builder_get_object(builder, "budget_note_dialog"));
+
+    gtk_window_set_transient_for(
+        GTK_WINDOW(dialog),
+        GTK_WINDOW(gnc_plugin_page_get_window(GNC_PLUGIN_PAGE(page))));
+
+    note = GTK_WIDGET(gtk_builder_get_object(builder, "BudgetNote"));
+    txt  = gnc_budget_get_account_period_note(priv->budget, acc, period_num);
+    xxxgtk_textview_set_text(GTK_TEXT_VIEW(note), txt);
+
+    gtk_widget_show_all(dialog);
+    result = gtk_dialog_run(GTK_DIALOG(dialog));
+    switch (result)
+    {
+    case GTK_RESPONSE_OK:
+        txt = xxxgtk_textview_get_text(GTK_TEXT_VIEW(note));
+        if (!strlen(txt))
+            txt = NULL;
+        gnc_budget_set_account_period_note(priv->budget, acc, period_num, txt);
+        break;
+    default:
+        break;
+    }
+    gtk_widget_destroy(dialog);
+    g_object_unref(G_OBJECT(builder));
+}
+
+static gboolean
+equal_fn (gpointer find_data, gpointer elt_data)
+{
+    return (find_data && (find_data == elt_data));
+}
+
+/* From the budget editor, open the budget report. This will reuse the
+   budget report if generated from the current budget editor. Note the
+   reuse is lost when GnuCash is restarted. This link may be restored
+   by: scan the current session tabs, identify reports, checking
+   whereby report's report-type matches a budget report, and the
+   report's budget option value matches the current budget. */
+static void
+gnc_plugin_page_budget_cmd_budget_report (GtkAction *action,
+                                          GncPluginPageBudget *page)
+{
+    GncPluginPageBudgetPrivate *priv;
+
+    g_return_if_fail (GNC_IS_PLUGIN_PAGE_BUDGET (page));
+
+    priv = GNC_PLUGIN_PAGE_BUDGET_GET_PRIVATE (page);
+
+    if (gnc_find_first_gui_component (WINDOW_REPORT_CM_CLASS, equal_fn,
+                                      priv->reportPage))
+        gnc_plugin_page_report_reload (GNC_PLUGIN_PAGE_REPORT (priv->reportPage));
+    else
+    {
+        SCM func = scm_c_eval_string ("gnc:budget-report-create");
+        SCM arg = SWIG_NewPointerObj (priv->budget, SWIG_TypeQuery ("_p_budget_s"), 0);
+        int report_id;
+
+        g_return_if_fail (scm_is_procedure (func));
+
+        arg = scm_apply_0 (func, scm_list_1 (arg));
+        g_return_if_fail (scm_is_exact (arg));
+
+        report_id = scm_to_int (arg);
+        g_return_if_fail (report_id >= 0);
+
+        priv->reportPage = gnc_plugin_page_report_new (report_id);
+    }
+
+    gnc_main_window_open_page (GNC_MAIN_WINDOW (priv->dialog), priv->reportPage);
+}
+
 static void
 gnc_plugin_page_budget_cmd_view_filter_by (GtkAction *action,
                                            GncPluginPageBudget *page)
