@@ -797,7 +797,7 @@ txn_transaction_cb(const AB_TRANSACTION *element, gpointer user_data)
             if (gnc_verify_dialog(
                         GTK_WINDOW (data->parent), FALSE, "%s",
                         _("The backend found an error during the preparation "
-                          "of the job. It is not possible to execute this job. \n"
+                          "of the job. It is not possible to execute this job.\n"
                           "\n"
                           "Most probably the bank does not support your chosen "
                           "job or your Online Banking account does not have the permission "
@@ -1130,12 +1130,12 @@ bal_accountinfo_cb(AB_IMEXPORTER_ACCOUNTINFO *element, gpointer user_data)
                      GTK_BUTTONS_OK,
                      "%s",
                      /* Translators: Strings from this file are needed only in
-                      * countries that have one of aqbanking's Online Banking
-                      * techniques available. This is 'OFX DirectConnect'
-                      * (U.S. and others), 'HBCI' (in Germany), or 'YellowNet'
-                      * (Switzerland). If none of these techniques are available
-                      * in your country, you may safely ignore strings from the
-                      * import-export/hbci subdirectory. */
+                        countries that have one of aqbanking's Online Banking
+                        techniques available. This is 'OFX DirectConnect'
+                        (U.S. and others), 'HBCI' (in Germany), or 'YellowNet'
+                        (Switzerland). If none of these techniques are available
+                        in your country, you may safely ignore strings from the
+                        import-export/hbci subdirectory. */
                      _("The downloaded Online Banking Balance was zero.\n\n"
                        "Either this is the correct balance, or your bank does not "
                        "support Balance download in this Online Banking version. "
@@ -1153,7 +1153,7 @@ bal_accountinfo_cb(AB_IMEXPORTER_ACCOUNTINFO *element, gpointer user_data)
 
         gchar *booked_str = gnc_AB_VALUE_to_readable_string(booked_val);
         gchar *message1 = g_strdup_printf(
-                              _("Result of Online Banking job: \n"
+                              _("Result of Online Banking job:\n"
                                 "Account booked balance is %s"),
                               booked_str);
         gchar *message2 =
