@@ -327,13 +327,7 @@ gnc_combo_cell_destroy (BasicCell* bcell)
             box->qf = NULL;
         }
 
-        for (node = box->ignore_strings; node; node = node->next)
-        {
-            g_free (node->data);
-            node->data = NULL;
-        }
-
-        g_list_free (box->ignore_strings);
+        g_list_free_full (box->ignore_strings, g_free);
         box->ignore_strings = NULL;
 
         g_free (box);
@@ -462,7 +456,6 @@ void
 gnc_combo_cell_add_account_menu_item (ComboCell* cell, char* menustr)
 {
     PopBox* box;
-    gchar* menu_copy, *value_copy;
 
     if (cell == NULL)
         return;
@@ -478,9 +471,10 @@ gnc_combo_cell_add_account_menu_item (ComboCell* cell, char* menustr)
         gnc_item_list_append (box->item_list, menustr);
         if (cell->cell.value)
         {
-            menu_copy = g_strdelimit (g_strdup (menustr), "-:/\\.", ' ');
-            value_copy =
-                g_strdelimit (g_strdup (cell->cell.value), "-:/\\.", ' ');
+            gchar* menu_copy = g_strdup (menustr);
+            gchar* value_copy = g_strdup (cell->cell.value);
+            g_strdelimit (menu_copy, "-:/\\.", ' ');
+            g_strdelimit (value_copy, "-:/\\.", ' ');
             if (strcmp (menu_copy, value_copy) == 0)
             {
                 gnc_combo_cell_set_value (cell, menustr);
@@ -635,19 +629,26 @@ gnc_combo_cell_modify_verify (BasicCell* _cell,
         if (change == NULL || *cursor_position < _cell->value_chars)
         {
             gnc_basic_cell_set_value_internal (_cell, newval);
+            *start_selection = *end_selection = *cursor_position;
             return;
         }
         match_str = quickfill_match (box->qf, newval);
+
+        if (match_str != NULL) // Do we have a quickfill match
+        {
+            *start_selection = newval_chars;
+            *end_selection = -1;
+            *cursor_position += change_chars;
+            box_str = match_str;
+
+            block_list_signals (cell); // Prevent recursion
+            gnc_item_list_select (box->item_list, match_str);
+            unblock_list_signals (cell);
+        }
     }
 
-    if (match_str != NULL)
-    {
-        *start_selection = newval_chars;
-        *end_selection = -1;
-        *cursor_position += change_chars;
-        box_str = match_str;
-    }
-    else if (cell->shared_store)
+    // Try using type-ahead
+    if (match_str == NULL && cell->shared_store)
     {
         // No start-of-name match, try type-ahead search, we match any substring of the full account name.
         GtkListStore *store = cell->shared_store;
@@ -655,23 +656,23 @@ gnc_combo_cell_modify_verify (BasicCell* _cell,
         *start_selection = newval_chars;
         *end_selection = -1;
         *cursor_position = newval_chars;
+
         // Do not change the string in the type-in box.
         box_str = newval;
     }
 
+    // No type-ahead / quickfill entry found
     if (match_str == NULL)
     {
+        block_list_signals (cell); // Prevent recursion
         if (cell->shared_store && gnc_item_list_using_temp (box->item_list))
         {
-            block_list_signals (cell); //Prevent recursion
             gnc_item_list_set_temp_store (box->item_list, NULL);
             gtk_list_store_clear (box->tmp_store);
-            unblock_list_signals (cell);
         }
-        gnc_basic_cell_set_value_internal (_cell, newval);
-        block_list_signals (cell);
         gnc_item_list_select (box->item_list, NULL);
         unblock_list_signals (cell);
+        gnc_basic_cell_set_value_internal (_cell, newval);
         *cursor_position = *start_selection = newval_chars;
         *end_selection = -1;
         return;
@@ -683,10 +684,6 @@ gnc_combo_cell_modify_verify (BasicCell* _cell,
         box->list_popped = TRUE;
     }
 
-    block_list_signals (cell);
-    gnc_item_list_select (box->item_list, match_str);
-    unblock_list_signals (cell);
-
     gnc_basic_cell_set_value_internal (_cell, box_str);
     g_free (match_str);
 }
@@ -916,7 +913,9 @@ popup_get_height (G_GNUC_UNUSED GtkWidget* widget,
     {
         gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin),
                                         GTK_POLICY_AUTOMATIC, GTK_POLICY_NEVER);
-        return height;
+        // if the list is empty height would be 0 so return 1 instead to
+        // satisfy the check_popup_height_is_true function
+        return height ? height : 1;
     }
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin),
                                     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -973,6 +972,7 @@ gnc_combo_cell_enter (BasicCell* bcell,
 {
     ComboCell* cell = (ComboCell*) bcell;
     PopBox* box = bcell->gui_private;
+    PopupToggle popup_toggle;
     GList* find = NULL;
 
     if (bcell->value)
@@ -999,6 +999,12 @@ gnc_combo_cell_enter (BasicCell* bcell,
     gnc_item_list_select (box->item_list, bcell->value);
     unblock_list_signals (cell);
 
+    popup_toggle = box->item_edit->popup_toggle;
+
+    // if the list is empty disable the toggle button
+    gtk_widget_set_sensitive (GTK_WIDGET(popup_toggle.tbutton),
+                              gnc_item_list_num_entries (box->item_list));
+
     combo_connect_signals (cell);
 
     *cursor_position = -1;
