@@ -893,21 +893,32 @@ xaccSplitEqual(const Split *sa, const Split *sb,
  * xaccSplitListGetUniqueTransactions
  ********************************************************************/
 GList *
-xaccSplitListGetUniqueTransactions(const GList *splits)
+xaccSplitListGetUniqueTransactionsReversed (const GList *splits)
 {
-    const GList *snode;
+    GHashTable *txn_hash = g_hash_table_new (NULL, NULL);
     GList *transList = NULL;
+    const GList *snode;
 
-    for(snode = splits; snode; snode = snode->next)
+    for (snode = splits; snode; snode = snode->next)
     {
         Transaction *trans = xaccSplitGetParent((Split *)(snode->data));
 
-        GList *item = g_list_find (transList, trans);
-        if (item == NULL)
-            transList = g_list_append (transList, trans);
+        if (g_hash_table_contains (txn_hash, trans))
+            continue;
+
+        g_hash_table_insert (txn_hash, trans, NULL);
+        transList = g_list_prepend (transList, trans);
     }
+    g_hash_table_destroy (txn_hash);
     return transList;
 }
+
+GList *
+xaccSplitListGetUniqueTransactions(const GList *splits)
+{
+    return g_list_reverse (xaccSplitListGetUniqueTransactionsReversed (splits));
+}
+
 /*################## Added for Reg2 #################*/
 
 
@@ -1104,6 +1115,7 @@ xaccSplitDetermineGainStatus (Split *split)
         other = (Split *) qof_collection_lookup_entity (col, guid);
         split->gains_split = other;
     }
+    g_value_unset (&v);
 }
 
 /********************************************************************\
@@ -1982,6 +1994,7 @@ xaccSplitMakeStockSplit(Split *s)
     mark_split(s);
     qof_instance_set_dirty(QOF_INSTANCE(s));
     xaccTransCommitEdit(s->parent);
+    g_value_unset (&v);
 }
 
 void
@@ -2113,11 +2126,14 @@ xaccSplitVoidFormerAmount(const Split *split)
 {
     GValue v = G_VALUE_INIT;
     gnc_numeric *num = NULL;
+    gnc_numeric retval;
     g_return_val_if_fail(split, gnc_numeric_zero());
     qof_instance_get_kvp (QOF_INSTANCE (split), &v, 1, void_former_amt_str);
     if (G_VALUE_HOLDS_BOXED (&v))
         num = (gnc_numeric*)g_value_get_boxed (&v);
-    return num ? *num : gnc_numeric_zero();
+    retval = num ? *num : gnc_numeric_zero();
+    g_value_unset (&v);
+    return retval;
 }
 
 gnc_numeric
@@ -2125,11 +2141,14 @@ xaccSplitVoidFormerValue(const Split *split)
 {
     GValue v = G_VALUE_INIT;
     gnc_numeric *num = NULL;
+    gnc_numeric retval;
     g_return_val_if_fail(split, gnc_numeric_zero());
     qof_instance_get_kvp (QOF_INSTANCE (split), &v, 1, void_former_val_str);
     if (G_VALUE_HOLDS_BOXED (&v))
         num = (gnc_numeric*)g_value_get_boxed (&v);
-    return num ? *num : gnc_numeric_zero();
+    retval = num ? *num : gnc_numeric_zero();
+    g_value_unset (&v);
+    return retval;
 }
 
 void
@@ -2142,6 +2161,7 @@ xaccSplitVoid(Split *split)
     num =  xaccSplitGetAmount(split);
     g_value_set_boxed (&v, &num);
     qof_instance_set_kvp (QOF_INSTANCE (split), &v, 1, void_former_amt_str);
+    g_value_reset (&v);
     num =  xaccSplitGetValue(split);
     g_value_set_boxed (&v, &num);
     qof_instance_set_kvp (QOF_INSTANCE (split), &v, 1, void_former_val_str);
@@ -2150,6 +2170,7 @@ xaccSplitVoid(Split *split)
     xaccSplitSetAmount (split, zero);
     xaccSplitSetValue (split, zero);
     xaccSplitSetReconcile(split, VREC);
+    g_value_unset (&v);
 }
 
 void
